@@ -24,17 +24,17 @@ class LangC(SetProject):
 
     def __init__(self, name='new-project'):
         super().__init__(name)
-        self.mfile = None
-        self.hfile = None
-        self.makef = None
-        self.sefile = ''
-        self.hefile = ''
+        self.src = self.path / "src"
+        self.obj = self.path / "obj"
+        self.inc = self.path / "inc"
+        self.mfile = self.src / "main.c"
+        self.makef = self.path / "Makefile"
         self.compiler = None
 
     def __writeToFiles(self):
         """write some initial data to files"""
         with open(self.mfile, 'w') as file:
-            file.writelines(f"""// main file
+            file.writelines("""// main file
 
 #include <stdio.h>
 
@@ -44,10 +44,22 @@ int main(int argc, char **argv) {{
 }}""")
 
         try:
-            with open(self.hefile, 'w') as file:
-                file.write("#pragma once")
-            with open(self.sefile, 'w') as file:
-                file.write(f"#include \"../inc/{self.hefile.stem}.h\"")
+            for gotFile in self.path.rglob("*.h"):
+                file_name = str(gotFile.stem)
+                with open(gotFile, 'w') as file:
+                    file.writelines(f"""// header file
+#ifndef _GUARD_{file_name.upper()}_H_
+#define _GUARD_{file_name.upper()}_H_
+
+// write here
+
+#endif""")
+                with open(self.src / (file_name + ".c"), 'w') as file:
+                    file.writelines(f"""// c file for \"{file_name}.h\"
+
+#include \"../inc/{file_name}.h\"
+
+// write here""")
         except AttributeError:
             pass
         except FileNotFoundError:
@@ -59,7 +71,8 @@ CC     = {self.compiler}
 CFLAG  = -Wall -std=c99
 CDFLAG = -Wall -std=c99 -g
 LD     = {self.compiler}
-LFLAG  = -v
+LDFLAG = -v
+LFLAG  =
 
 
 SRC_DIR   = src
@@ -102,7 +115,7 @@ ${{DEBUG_DIR}}/%.o: ${{SRC_DIR}}/%.c
 
 ${{DEBUG_BIN}}: ${{DEBUG_OBJ}}
 \t-@echo "Linking to -> $@"
-\t${{LD}} ${{LFLAG}} -o $@ ${{DEBUG_DIR}}/*.o
+\t${{LD}} ${{LDFLAG}} -o $@ ${{DEBUG_DIR}}/*.o
 
 
 clean:
@@ -112,20 +125,21 @@ clean:
 .PHONY: all dir debug clean""")
 
     def setup(self):
-        src = self.path / 'src'
-        obj = self.path / 'obj'
-        inc = self.path / 'inc'
-        self.mfile = src / 'main.c'
-        self.hfile = input("Press enter if don't want header file created: ")
-        self.makef = self.path / 'Makefile'
-        src.mkdir()
+        """general setup for setting up C lang project"""
+        self.src.mkdir()
         Path.touch(self.mfile)
-        if self.hfile:
-            inc.mkdir()
-            self.hefile = inc / (self.hfile + '.h')
-            self.sefile = src / (self.hfile + '.c')
-            Path.touch(self.hefile)
-            Path.touch(self.sefile)
+        header_count = input("Give number of header files you want to create[leave blank for none]: ")
+        if header_count:
+            try:
+                header_count = int(header_count)
+            except ValueError:
+                print("No header file created")
+            else:
+                self.inc.mkdir()
+                for count in range(header_count):
+                    file_name = input(str(count + 1) + ": ")
+                    Path.touch(self.inc / (file_name + ".h"))
+                    Path.touch(self.src / (file_name + ".c"))
         self.compiler = input("Select compiler[defualt to clang]: ")
         if not self.compiler:
             self.compiler = "clang"
@@ -138,17 +152,18 @@ class LangCpp(SetProject):
 
     def __init__(self, name='new-project'):
         super().__init__(name)
-        self.mfile = None
-        self.hfile = None
-        self.makef = None
-        self.sefile = ''
-        self.hefile = ''
+        self.src = self.path / "src"
+        self.obj = self.path / "obj"
+        self.inc = self.path / "inc"
+        self.mfile = self.src / "main.cpp"
+        self.makef = self.path / "Makefile"
         self.compiler = None
 
-    def __writeToFiles(self):
+    def __writeToFiles(self, for_cp = False):
         """write some initial data to files"""
         with open(self.mfile, 'w') as file:
-            file.writelines(f"""// main file
+            if not for_cp:
+                file.writelines("""// main file
 
 #include <iostream>
 
@@ -156,12 +171,115 @@ int main(int argc, char **argv) {{
 \t/* code here */
 \treturn 0;
 }}""")
+            else:
+                file.writelines(f"""// main file
+
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wcomment"
+
+#include <bits/stdc++.h>
+
+using namespace std;
+
+#define ll long long
+#define lD long double
+#define rep(n) for (int i = 0; i < (int)n; i++)
+#define repl(n) for (ll i = 0; i < (ll)n; i++)
+#define repd(i, n) for (int i = n - 1; i >= 0; i--)
+#define repld(i, n) for (ll i = n - 1; i >= 0; i--)
+#define loop(i,a,b) for (int i = (int)a; i < (int)b; i++)
+#define rloop(i,a,b) for (int i = (int)a; i <= (int)b; i++)
+#define loopl(i,a,b) for (ll i = (ll)a; i < (ll)b; ++i)
+#define rloopl(i,a,b) for (ll i = (ll)a; i <= (ll)b; ++i)
+#define loopd(i,a,b) for (int i = (int)a; i > b; i--)
+#define rloopd(i,a,b) for (int i = (int)a; i >= b; i--)
+#define loopld(i,a,b) for (ll i = (ll)a; i > b; i--)
+#define rloopld(i,a,b) for (ll i = (ll)a; i >= b; i--)
+#define WL(t) while(t--)
+#define pb push_back
+#define eb emplace_back
+#define ab(a) (a < 0)?(-1*a):a
+#define mset(a,b,c) loop(i,0,b) a[i]=c
+#define asum(a,b,c) WL(b) {{ (c) += (a)[(b)]; }}
+#define F first
+#define S second
+#define mp make_pair
+#define clr(x) x.clear()
+#define itoc(c) ((char)(((int)'0')+c))
+#define all(p) p.begin(),p.end()
+#define max(x,y) (x>y)?x:y
+#define min(x,y) (x<y)?x:y
+#define remax(a,b) (a = max(a,b))
+#define remin(a,b) (a = min(a,b))
+#define mid(s,e) (s+(e-s)/2)
+#define PQ(type) priority_queue<type>
+#define PQD(type) priority_queue<type,vector<type>,greater<type>>
+#define SZ(x) ((int)(x).size())
+#define inrange(i,a,b) ((i>=min(a,b)) && (i<=max(a,b)))
+
+#define fileI(name) \\
+	freopen(name".in", "r", stdin);
+#define fileIO(name) \\
+	freopen(name".in", "r", stdin); \\
+	freopen(name".out", "w", stdout);
+#define FAST_IO \\
+	ios_base::sync_with_stdio(false); \\
+	cin.tie(NULL); \\
+	cout.tie(NULL);
+
+typedef vector<int> vi;
+typedef vector<vector<int>> vvi;
+typedef pair<ll, ll> pll;
+typedef pair<int, int> pii;
+typedef vector<pll> vpll;
+typedef vector<pii> vpii;
+
+template<typename T> T gcd(T a, T b) {{ return (b?__gcd(a,b):a); }}
+template<typename T> T lcm(T a, T b) {{ return (a*(b/gcd(a,b))); }}
+
+void solvethetestcase();
+
+signed main() {{
+	// comment when using scanf, printf \\
+	FAST_IO
+
+	// comment for input through console
+	fileI("input")
+
+	int t = 1;
+	// (uncomment for multiple test cases) \\
+	cin >> t;
+	loopl (testcase, 1, t + 1) {{
+		// (uncomment for codejam) \\
+		printf("Case #%lld: ", testcase);
+		solvethetestcase();
+    }}
+}}
+
+void solvethetestcase() {{
+    // write here
+}}
+
+#pragma GCC diagnostic pop""")
 
         try:
-            with open(self.hefile, 'w') as file:
-                file.write("#pragma once")
-            with open(self.sefile, 'w') as file:
-                file.write(f"#include \"../inc/{self.hefile.stem}.hpp\"")
+            for gotFile in self.path.rglob("*.hpp"):
+                file_name = str(gotFile.stem)
+                with open(gotFile, 'w') as file:
+                    file.writelines(f"""// header file
+
+#ifndef _GUARD_{file_name.upper()}_HPP_
+#define _GUARD_{file_name.upper()}_HPP_
+
+// write here
+
+#endif""")
+                with open(self.src / (file_name + ".cpp"), 'w') as file:
+                    file.writelines(f"""// cpp file for \"{file_name}.hpp\"
+
+#include \"../inc/{file_name}.hpp\"
+
+// write here""")
         except AttributeError:
             pass
         except FileNotFoundError:
@@ -173,7 +291,8 @@ CC     = {self.compiler}
 CFLAG  = -Wall -std=c++14
 CDFLAG = -Wall -std=c++14 -g
 LD     = {self.compiler}
-LFLAG  = -v
+LDFLAG = -v
+LFLAG  =
 
 
 SRC_DIR   = src
@@ -216,34 +335,40 @@ ${{DEBUG_DIR}}/%.o: ${{SRC_DIR}}/%.cpp
 
 ${{DEBUG_BIN}}: ${{DEBUG_OBJ}}
 \t-@echo "Linking to -> $@"
-\t${{LD}} ${{LFLAG}} -o $@ ${{DEBUG_DIR}}/*.o
+\t${{LD}} ${{LDFLAG}} -o $@ ${{DEBUG_DIR}}/*.o
 
 
 clean:
-\trm -rf ${{DIRS}}
+\trm -rf ${{DIRS}} $(notdir $(realpath .))
 
 .SILENT:
 .PHONY: all dir debug clean""")
 
     def setup(self):
-        src = self.path / 'src'
-        obj = self.path / 'obj'
-        inc = self.path / 'inc'
-        self.mfile = src / 'main.cpp'
-        self.hfile = input("Press enter if don't want header file created: ")
-        self.makef = self.path / 'Makefile'
-        src.mkdir()
+        """general setup for setting up C++ lang project"""
+        self.src.mkdir()
         Path.touch(self.mfile)
-        if self.hfile:
-            inc.mkdir()
-            self.hefile = inc / (self.hfile + '.hpp')
-            self.sefile = src / (self.hfile + '.cpp')
-            Path.touch(self.hefile)
-            Path.touch(self.sefile)
+        for_cp = input("is the setup for competitive coding? [y/n](no option is considered no): ")
+        if for_cp == '' or for_cp == 'n':
+            for_cp = False
+        else:
+            for_cp = True
+        headers_count = input("Give number of header files you want to create[leave blank for none]: ")
+        if headers_count:
+            try:
+                headers_count = int(headers_count)
+            except ValueError:
+                print("No header file created")
+            else:
+                self.inc.mkdir()
+                for count in range(headers_count):
+                    file_name = input(str(count + 1) + ": ")
+                    Path.touch(self.inc / (file_name + ".hpp"))
+                    Path.touch(self.src / (file_name + ".cpp"))
         self.compiler = input("Enter compiler[defualt is clang++]: ")
         if not self.compiler:
             self.compiler = "clang++"
-        LangCpp.__writeToFiles(self)
+        LangCpp.__writeToFiles(self, for_cp)
 
 
 class LangJava(SetProject):
@@ -257,6 +382,7 @@ class LangJava(SetProject):
         self.packageDir = None
 
     def __writeToFiles(self):
+        """write some initial data to files"""
         for gotFile in self.dsrc.rglob("*.java"):
             with open(gotFile, 'w') as file:
                 if gotFile.stem == "Main":
@@ -275,16 +401,18 @@ class {gotFile.stem} {{
 }}""")
 
     def setup(self):
+        """general setup for setting JAVA lang project"""
         self.dsrc = self.path / 'src'
         self.dbin = self.path / 'bin'
         self.packageName = input("Package Name [if not provided, default will be hostname]: ")
         if not self.packageName:
             self.packageDir = self.dsrc / ('com') / uname()[1]
+            self.packageName = uname()[1]
         else:
             self.packageDir = self.dsrc / ('com') / self.packageName
         className = list()
         try:
-            count = int(input('Number of class files(except Main.java): '))
+            count = int(input('Number of class files(except Main.java)[Enter 0 if none]: '))
         except ValueError as ve:
             print("Enter correct values: " + ve)
         else:
@@ -325,12 +453,13 @@ class LangJavaFx(LangJava):
         self.javaFiles = list()
 
     def __getJavaFiles(self):
+        """take all java files as input from user"""
         for file in self.dsrc.rglob("*.java"):
             self.javaFiles.append(file)
         print(self.javaFiles)
 
     def __writeToFiles(self):
-        # for gotFile in self.dsrc.rglob("*.java"):
+        """write some initial data to files"""
         for gotFile in self.javaFiles:
             with open(gotFile, "w") as file:
                 if gotFile.stem == "Main":
@@ -478,6 +607,7 @@ rsync -a {self.dsrc}/com/{self.packageName}/{Path(self.cssFile).stem}.css {self.
 # provide further sync details here""")
 
     def doFurtherSetup(self):
+        """general setup for settin up JAVAFX project(additional after JAVA setup)"""
         self.fxmlFile = input("Enter the fxml file name[if not, leave blank]: ")
         self.cssFile = input("Enter the css file name[if not, leave blank]: ")
         print("Enter scenebuilder position")
@@ -503,6 +633,7 @@ class LangServlet(SetProject):
         self.packageName = None
 
     def __writeToFiles(self):
+        """write some initial data to files"""
         with open(self.path / "index.html", 'w') as file:
             file.writelines(f"""<!DOCTYPE html>
 <html>
@@ -542,6 +673,7 @@ public class {javafile.stem.title()} extends HttpServlet {{
 
 
     def setup(self):
+        """general setup for setting up JAVA SERVLET project"""
         src = self.path / 'src'
         classes = self.path / 'WEB-INF' / 'classes'
         findex = self.path / 'index.html'
@@ -592,6 +724,7 @@ class LangPython(SetProject):
         self.path = None
 
     def setup(self):
+        """general setup for setting up a PYTHON project"""
         choiceVenv = input("Want virtualenv setup for python? [y/n]: ")
         if choiceVenv == "y":
             directory = input('Enter dir name(blank for current dir): ')
@@ -642,6 +775,7 @@ class LangWebD(SetProject):
         super().__init__(name)
 
     def setup(self):
+        """general setup for setting up WEB-DESIGNING project"""
         index = self.path / 'index.html'
         style = self.path / 'style.css'
         script = self.path / 'script.js'
